==> json_theme-4.0.0%2B6.tar.gz: lib/src/schema/schemas.dart <==
import 'all.dart';

class Schemas {
  static final all = <String, Map<String, dynamic>>{
    AlignmentSchema.id: AlignmentSchema.schema,
    AndroidOverscrollIndicatorSchema.id:
        AndroidOverscrollIndicatorSchema.schema,
    AppBarThemeSchema.id: AppBarThemeSchema.schema,
    AutovalidateModeSchema.id: AutovalidateModeSchema.schema,
    AxisSchema.id: AxisSchema.schema,
    BlendModeSchema.id: BlendModeSchema.schema,
    BlurStyleSchema.id: BlurStyleSchema.schema,
    BorderRadiusSchema.id: BorderRadiusSchema.schema,
    BorderSideSchema.id: BorderSideSchema.schema,
    BorderStyleSchema.id: BorderStyleSchema.schema,
    BottomAppBarThemeScheme.id: BottomAppBarThemeScheme.schema,
    BottomNavigationBarLandscapeLayoutSchema.id:
        BottomNavigationBarLandscapeLayoutSchema.schema,
    BottomNavigationBarThemeDataSchema.id:
        BottomNavigationBarThemeDataSchema.schema,
    BottomNavigationBarTypeSchema.id: BottomNavigationBarTypeSchema.schema,
    BottomSheetThemeDataSchema.id: BottomSheetThemeDataSchema.schema,
    BoxBorderSchema.id: BoxBorderSchema.schema,
    BoxConstraintsSchema.id: BoxConstraintsSchema.schema,
    BoxDecorationSchema.id: BoxDecorationSchema.schema,
    BoxFitSchema.id: BoxFitSchema.schema,
    BoxShadowSchema.id: BoxShadowSchema.schema,
    BoxShapeSchema.id: BoxShapeSchema.schema,
    BrightnessSchema.id: BrightnessSchema.schema,
    ButtonBarLayoutBehaviorSchema.id: ButtonBarLayoutBehaviorSchema.schema,
    ButtonBarThemeDataSchema.id: ButtonBarThemeDataSchema.schema,
    ButtonStyleSchema.id: ButtonStyleSchema.schema,
    ButtonTextThemeSchema.id: ButtonTextThemeSchema.schema,
    ButtonThemeDataSchema.id: ButtonThemeDataSchema.schema,
    CardThemeSchema.id: CardThemeSchema.schema,
    CheckboxThemeDataSchema.id: CheckboxThemeDataSchema.schema,
    ChipThemeDataSchema.id: ChipThemeDataSchema.schema,
    ClipSchema.id: ClipSchema.schema,
    ColorSchema.id: ColorSchema.schema,
    ColorSchemeSchema.id: ColorSchemeSchema.schema,
    CrossAxisAlignmentSchema.id: CrossAxisAlignmentSchema.schema,
    CrossFadeStateSchema.id: CrossFadeStateSchema.schema,
    CupertinoTextThemeDataSchema.id: CupertinoTextThemeDataSchema.schema,
    CupertinoThemeDataSchema.id: CupertinoThemeDataSchema.schema,
    DataTableThemeDataSchema.id: DataTableThemeDataSchema.schema,
    DecorationImageSchema.id: DecorationImageSchema.schema,
    DecorationPositionSchema.id: DecorationPositionSchema.schema,
    DialogThemeSchema.id: DialogThemeSchema.schema,
    DividerThemeDataSchema.id: DividerThemeDataSchema.schema,
    DragStartBehaviorSchema.id: DragStartBehaviorSchema.schema,
    DrawerThemeDataSchema.id: DrawerThemeDataSchema.schema,
    EdgeInsetsGeometrySchema.id: EdgeInsetsGeometrySchema.schema,
    ElevatedButtonThemeDataSchema.id: ElevatedButtonThemeDataSchema.schema,
    ExpansionTileThemeDataSchema.id: ExpansionTileThemeDataSchema.schema,
    FilterQualitySchema.id: FilterQualitySchema.schema,
    FlexFitSchema.id: FlexFitSchema.schema,
    FloatingActionButtonAnimatorSchema.id:
        FloatingActionButtonAnimatorSchema.schema,
    FloatingActionButtonLocationSchema.id:
        FloatingActionButtonLocationSchema.schema,
    FloatingActionButtonThemeDataSchema.id:
        FloatingActionButtonThemeDataSchema.schema,
    FloatingLabelAlignmentSchema.id: FloatingLabelAlignmentSchema.schema,
    FloatingLabelBehaviorSchema.id: FloatingLabelBehaviorSchema.schema,
    FontFeatureSchema.id: FontFeatureSchema.schema,
    FontStyleSchema.id: FontStyleSchema.schema,
    FontWeightSchema.id: FontWeightSchema.schema,
    GradientSchema.id: GradientSchema.schema,
    GradientTransformSchema.id: GradientTransformSchema.schema,
    HitTestBehaviorSchema.id: HitTestBehaviorSchema.schema,
    IconDataSchema.id: IconDataSchema.schema,
    IconThemeDataSchema.id: IconThemeDataSchema.schema,
    ImageProviderSchema.id: ImageProviderSchema.schema,
    ImageRepeatSchema.id: ImageRepeatSchema.schema,
    InputBorderSchema.id: InputBorderSchema.schema,
    InputDecorationThemeSchema.id: InputDecorationThemeSchema.schema,
    InteractiveInkFeatureFactorySchema.id:
        InteractiveInkFeatureFactorySchema.schema,
    ListTileStyleSchema.id: ListTileStyleSchema.schema,
    ListTileThemeDataSchema.id: ListTileThemeDataSchema.schema,
    LocaleSchema.id: LocaleSchema.schema,
    MainAxisAlignmentSchema.id: MainAxisAlignmentSchema.schema,
    MainAxisSizeSchema.id: MainAxisSizeSchema.schema,
    MaterialBannerThemeDataSchema.id: MaterialBannerThemeDataSchema.schema,
    MaterialColorSchema.id: MaterialColorSchema.schema,
    MaterialStatePropertyBoolSchema.id: MaterialStatePropertyBoolSchema.schema,
    MaterialStatePropertyBorderSideSchema.id:
        MaterialStatePropertyBorderSideSchema.schema,
    MaterialStatePropertyColorSchema.id:
        MaterialStatePropertyColorSchema.schema,
    MaterialStatePropertyDoubleSchema.id:
        MaterialStatePropertyDoubleSchema.schema,
    MaterialStatePropertyEdgeInsetsGeometrySchema.id:
        MaterialStatePropertyEdgeInsetsGeometrySchema.schema,
    MaterialStatePropertyIconThemeDataSchema.id:
        MaterialStatePropertyIconThemeDataSchema.schema,
    MaterialStatePropertyMouseCursorSchema.id:
        MaterialStatePropertyMouseCursorSchema.schema,
    MaterialStatePropertyOutlinedBorderSchema.id:
        MaterialStatePropertyOutlinedBorderSchema.schema,
    MaterialStatePropertySizeSchema.id: MaterialStatePropertySizeSchema.schema,
    MaterialStatePropertyTextStyleSchema.id:
        MaterialStatePropertyTextStyleSchema.schema,
    MaterialTapTargetSizeSchema.id: MaterialTapTargetSizeSchema.schema,
    MaterialTypeSchema.id: MaterialTypeSchema.schema,
    Matrix4Schema.id: Matrix4Schema.schema,
    MaxLengthEnforcementSchema.id: MaxLengthEnforcementSchema.schema,
    MouseCursorSchema.id: MouseCursorSchema.schemas,
    NavigationBarThemeDataSchema.id: NavigationBarThemeDataSchema.schema,
    NavigationDestinationLabelBehaviorSchema.id:
        NavigationDestinationLabelBehaviorSchema.schema,
    NavigationRailLabelTypeSchema.id: NavigationRailLabelTypeSchema.schema,
    NavigationRailThemeDataSchema.id: NavigationRailThemeDataSchema.schema,
    NotchedShapeSchema.id: NotchedShapeSchema.schema,
    OffsetSchema.id: OffsetSchema.schema,
    OrdinalSortKeySchema.id: OrdinalSortKeySchema.schema,
    OutlinedBorderSchema.id: OutlinedBorderSchema.schema,
    OutlinedButtonThemeDataSchema.id: OutlinedButtonThemeDataSchema.schema,
    PageTransitionsBuilderSchema.id: PageTransitionsBuilderSchema.schema,
    PageTransitionsThemeSchema.id: PageTransitionsThemeSchema.schema,
    PopupMenuPositionSchema.id: PopupMenuPositionSchema.schema,
    PopupMenuThemeDataSchema.id: PopupMenuThemeDataSchema.schema,
    ProgressIndicatorThemeDataSchema.id:
        ProgressIndicatorThemeDataSchema.schema,
    RadioThemeDataSchema.id: RadioThemeDataSchema.schema,
    RadiusSchema.id: RadiusSchema.schema,
    RangeSliderThumbShapeSchema.id: RangeSliderThumbShapeSchema.schema,
    RangeSliderTickMarkShapeSchema.id: RangeSliderTickMarkShapeSchema.schema,
    RangeSliderTrackShapeSchema.id: RangeSliderTrackShapeSchema.schema,
    RangeSliderValueIndicatorShapeSchema.id:
        RangeSliderValueIndicatorShapeSchema.schema,
    RectSchema.id: RectSchema.schema,
    ScrollBehaviorSchema.id: ScrollBehaviorSchema.schema,
    ScrollPhysicsSchema.id: ScrollPhysicsSchema.schema,
    ScrollViewKeyboardDismissBehaviorSchema.id:
        ScrollViewKeyboardDismissBehaviorSchema.schema,
    ScrollbarOrientationSchema.id: ScrollbarOrientationSchema.schema,
    ScrollbarThemeDataSchema.id: ScrollbarThemeDataSchema.schema,
    SemanticsTagSchema.id: SemanticsTagSchema.schema,
    ShadowSchema.id: ShadowSchema.schema,
    ShapeBorderSchema.id: ShapeBorderSchema.schema,
    ShowValueIndicatorSchema.id: ShowValueIndicatorSchema.schema,
    SizeSchema.id: SizeSchema.schema,
    SliderComponentShapeSchema.id: SliderComponentShapeSchema.schema,
    SliderThemeDataSchema.id: SliderThemeDataSchema.schema,
    SliderTickMarkShapeSchema.id: SliderTickMarkShapeSchema.schema,
    SliderTrackShapeSchema.id: SliderTrackShapeSchema.schema,
    SmartDashesTypeSchema.id: SmartDashesTypeSchema.schema,
    SmartQuotesTypeSchema.id: SmartQuotesTypeSchema.schema,
    SnackBarBehaviorSchema.id: SnackBarBehaviorSchema.schema,
    SnackBarThemeDataSchema.id: SnackBarThemeDataSchema.schema,
    StackFitSchema.id: StackFitSchema.schema,
    StrutStyleSchema.id: StrutStyleSchema.schema,
    SwitchThemeDataSchema.id: SwitchThemeDataSchema.schema,
    SystemUiOverlayStyleSchema.id: SystemUiOverlayStyleSchema.schema,
    TabBarIndicatorSizeSchema.id: TabBarIndicatorSizeSchema.schema,
    TabBarThemeSchema.id: TabBarThemeSchema.schema,
    TableBorderSchema.id: TableBorderSchema.schema,
    TableColumnWidthSchema.id: TableColumnWidthSchema.schema,
    TargetPlatformSchema.id: TargetPlatformSchema.schema,
    TextAlignSchema.id: TextAlignSchema.schema,
    TextAlignVerticalSchema.id: TextAlignVerticalSchema.schema,
    TextBaselineSchema.id: TextBaselineSchema.schema,
    TextButtonThemeDataSchema.id: TextButtonThemeDataSchema.schema,
    TextCapitalizationSchema.id: TextCapitalizationSchema.schema,
    TextDecorationSchema.id: TextDecorationSchema.schema,
    TextDecorationStyleSchema.id: TextDecorationStyleSchema.schema,
    TextDirectionSchema.id: TextDirectionSchema.schema,
    TextHeightBehaviorSchema.id: TextHeightBehaviorSchema.schema,
    TextInputActionSchema.id: TextInputActionSchema.schema,
    TextInputTypeSchema.id: TextInputTypeSchema.schema,
    TextLeadingDistributionSchema.id: TextLeadingDistributionSchema.schema,
    TextOverflowSchema.id: TextOverflowSchema.schema,
    TextSelectionThemeDataSchema.id: TextSelectionThemeDataSchema.schema,
    TextStyleSchema.id: TextStyleSchema.schema,
    TextThemeSchema.id: TextThemeSchema.schema,
    TextWidthBasisSchema.id: TextWidthBasisSchema.schema,
    ThemeDataSchema.id: ThemeDataSchema.schema,
    TileModeSchema.id: TileModeSchema.schema,
    TimePickerThemeDataSchema.id: TimePickerThemeDataSchema.schema,
    ToggleButtonsThemeDataSchema.id: ToggleButtonsThemeDataSchema.schema,
    ToolbarOptionsSchema.id: ToolbarOptionsSchema.schema,
    TooltipThemeDataSchema.id: TooltipThemeDataSchema.schema,
    TooltipTriggerModeSchema.id: TooltipTriggerModeSchema.schema,
    TypographySchema.id: TypographySchema.schema,
    VerticalDirectionSchema.id: VerticalDirectionSchema.schema,
    VisualDensitySchema.id: VisualDensitySchema.schema,
    WrapAlignmentSchema.id: WrapAlignmentSchema.schema,
    WrapCrossAlignmentSchema.id: WrapCrossAlignmentSchema.schema,
  };
}

==> json_theme-5.0.2%2B6.tar.gz: lib/src/schema/schemas.dart <==
import 'all.dart';

class Schemas {
  static final all = <String, Map<String, dynamic>>{
    AlignmentDirectionalSchema.id: AlignmentDirectionalSchema.schema,
    AlignmentGeometrySchema.id: AlignmentGeometrySchema.schema,
    AlignmentSchema.id: AlignmentSchema.schema,
    AndroidOverscrollIndicatorSchema.id:
        AndroidOverscrollIndicatorSchema.schema,
    AppBarThemeSchema.id: AppBarThemeSchema.schema,
    AutovalidateModeSchema.id: AutovalidateModeSchema.schema,
    AxisSchema.id: AxisSchema.schema,
    BlendModeSchema.id: BlendModeSchema.schema,
    BlurStyleSchema.id: BlurStyleSchema.schema,
    BorderRadiusSchema.id: BorderRadiusSchema.schema,
    BorderSideSchema.id: BorderSideSchema.schema,
    BorderStyleSchema.id: BorderStyleSchema.schema,
    BottomAppBarThemeScheme.id: BottomAppBarThemeScheme.schema,
    BottomNavigationBarLandscapeLayoutSchema.id:
        BottomNavigationBarLandscapeLayoutSchema.schema,
    BottomNavigationBarThemeDataSchema.id:
        BottomNavigationBarThemeDataSchema.schema,
    BottomNavigationBarTypeSchema.id: BottomNavigationBarTypeSchema.schema,
    BottomSheetThemeDataSchema.id: BottomSheetThemeDataSchema.schema,
    BoxBorderSchema.id: BoxBorderSchema.schema,
    BoxConstraintsSchema.id: BoxConstraintsSchema.schema,
    BoxDecorationSchema.id: BoxDecorationSchema.schema,
    BoxFitSchema.id: BoxFitSchema.schema,
    BoxShadowSchema.id: BoxShadowSchema.schema,
    BoxShapeSchema.id: BoxShapeSchema.schema,
    BrightnessSchema.id: BrightnessSchema.schema,
    ButtonBarLayoutBehaviorSchema.id: ButtonBarLayoutBehaviorSchema.schema,
    ButtonBarThemeDataSchema.id: ButtonBarThemeDataSchema.schema,
    ButtonStyleSchema.id: ButtonStyleSchema.schema,
    ButtonTextThemeSchema.id: ButtonTextThemeSchema.schema,
    ButtonThemeDataSchema.id: ButtonThemeDataSchema.schema,
    CardThemeSchema.id: CardThemeSchema.schema,
    CheckboxThemeDataSchema.id: CheckboxThemeDataSchema.schema,
    ChipThemeDataSchema.id: ChipThemeDataSchema.schema,
    ClipSchema.id: ClipSchema.schema,
    ColorFilterSchema.id: ColorFilterSchema.schema,
    ColorSchema.id: ColorSchema.schema,
    ColorSchemeSchema.id: ColorSchemeSchema.schema,
    CrossAxisAlignmentSchema.id: CrossAxisAlignmentSchema.schema,
    CrossFadeStateSchema.id: CrossFadeStateSchema.schema,
    CupertinoTextThemeDataSchema.id: CupertinoTextThemeDataSchema.schema,
    CupertinoThemeDataSchema.id: CupertinoThemeDataSchema.schema,
    DataTableThemeDataSchema.id: DataTableThemeDataSchema.schema,
    DecorationImageSchema.id: DecorationImageSchema.schema,
    DecorationPositionSchema.id: DecorationPositionSchema.schema,
    DialogThemeSchema.id: DialogThemeSchema.schema,
    DividerThemeDataSchema.id: DividerThemeDataSchema.schema,
    DragStartBehaviorSchema.id: DragStartBehaviorSchema.schema,
    DrawerThemeDataSchema.id: DrawerThemeDataSchema.schema,
    EdgeInsetsGeometrySchema.id: EdgeInsetsGeometrySchema.schema,
    ElevatedButtonThemeDataSchema.id: ElevatedButtonThemeDataSchema.schema,
    ExpansionTileThemeDataSchema.id: ExpansionTileThemeDataSchema.schema,
    FilledButtonThemeDataSchema.id: FilledButtonThemeDataSchema.schema,
    FilterQualitySchema.id: FilterQualitySchema.schema,
    FlexFitSchema.id: FlexFitSchema.schema,
    FloatingActionButtonAnimatorSchema.id:
        FloatingActionButtonAnimatorSchema.schema,
    FloatingActionButtonLocationSchema.id:
        FloatingActionButtonLocationSchema.schema,
    FloatingActionButtonThemeDataSchema.id:
        FloatingActionButtonThemeDataSchema.schema,
    FloatingLabelAlignmentSchema.id: FloatingLabelAlignmentSchema.schema,
    FloatingLabelBehaviorSchema.id: FloatingLabelBehaviorSchema.schema,
    FontFeatureSchema.id: FontFeatureSchema.schema,
    FontStyleSchema.id: FontStyleSchema.schema,
    FontWeightSchema.id: FontWeightSchema.schema,
    FontVariationSchema.id: FontVariationSchema.schema,
    GradientSchema.id: GradientSchema.schema,
    GradientTransformSchema.id: GradientTransformSchema.schema,
    HitTestBehaviorSchema.id: HitTestBehaviorSchema.schema,
    IconButtonThemeDataSchema.id: IconButtonThemeDataSchema.schema,
    IconSchema.id: IconSchema.schema,
    IconDataSchema.id: IconDataSchema.schema,
    IconThemeDataSchema.id: IconThemeDataSchema.schema,
    ImageProviderSchema.id: ImageProviderSchema.schema,
    ImageRepeatSchema.id: ImageRepeatSchema.schema,
    InputBorderSchema.id: InputBorderSchema.schema,
    InputDecorationThemeSchema.id: InputDecorationThemeSchema.schema,
    InteractiveInkFeatureFactorySchema.id:
        InteractiveInkFeatureFactorySchema.schema,
    ListTileStyleSchema.id: ListTileStyleSchema.schema,
    ListTileThemeDataSchema.id: ListTileThemeDataSchema.schema,
    LocaleSchema.id: LocaleSchema.schema,
    MainAxisAlignmentSchema.id: MainAxisAlignmentSchema.schema,
    MainAxisSizeSchema.id: MainAxisSizeSchema.schema,
    MaterialBannerThemeDataSchema.id: MaterialBannerThemeDataSchema.schema,
    MaterialColorSchema.id: MaterialColorSchema.schema,
    MaterialStatePropertyBoolSchema.id: MaterialStatePropertyBoolSchema.schema,
    MaterialStatePropertyBorderSideSchema.id:
        MaterialStatePropertyBorderSideSchema.schema,
    MaterialStatePropertyColorSchema.id:
        MaterialStatePropertyColorSchema.schema,
    MaterialStatePropertyDoubleSchema.id:
        MaterialStatePropertyDoubleSchema.schema,
    MaterialStatePropertyEdgeInsetsGeometrySchema.id:
        MaterialStatePropertyEdgeInsetsGeometrySchema.schema,
    MaterialStatePropertyIconSchema.id: MaterialStatePropertyIconSchema.schema,
    MaterialStatePropertyIconThemeDataSchema.id:
        MaterialStatePropertyIconThemeDataSchema.schema,
    MaterialStatePropertyMouseCursorSchema.id:
        MaterialStatePropertyMouseCursorSchema.schema,
    MaterialStatePropertyOutlinedBorderSchema.id:
        MaterialStatePropertyOutlinedBorderSchema.schema,
    MaterialStatePropertySizeSchema.id: MaterialStatePropertySizeSchema.schema,
    MaterialStatePropertyTextStyleSchema.id:
        MaterialStatePropertyTextStyleSchema.schema,
    MaterialTapTargetSizeSchema.id: MaterialTapTargetSizeSchema.schema,
    MaterialTypeSchema.id: MaterialTypeSchema.schema,
    Matrix4Schema.id: Matrix4Schema.schema,
    MaxLengthEnforcementSchema.id: MaxLengthEnforcementSchema.schema,
    MenuBarThemeDataSchema.id: MenuBarThemeDataSchema.schema,
    MenuButtonThemeDataSchema.id: MenuButtonThemeDataSchema.schema,
    MenuStyleSchema.id: MenuStyleSchema.schema,
    MenuThemeDataSchema.id: MenuThemeDataSchema.schema,
    MouseCursorSchema.id: MouseCursorSchema.schemas,
    NavigationBarThemeDataSchema.id: NavigationBarThemeDataSchema.schema,
    NavigationDestinationLabelBehaviorSchema.id:
        NavigationDestinationLabelBehaviorSchema.schema,
    NavigationRailLabelTypeSchema.id: NavigationRailLabelTypeSchema.schema,
    NavigationRailThemeDataSchema.id: NavigationRailThemeDataSchema.schema,
    NotchedShapeSchema.id: NotchedShapeSchema.schema,
    OffsetSchema.id: OffsetSchema.schema,
    OrdinalSortKeySchema.id: OrdinalSortKeySchema.schema,
    OutlinedBorderSchema.id: OutlinedBorderSchema.schema,
    OutlinedButtonThemeDataSchema.id: OutlinedButtonThemeDataSchema.schema,
    PanAxisSchema.id: PanAxisSchema.schema,
    PageTransitionsBuilderSchema.id: PageTransitionsBuilderSchema.schema,
    PageTransitionsThemeSchema.id: PageTransitionsThemeSchema.schema,
    PointerDeviceKindSchema.id: PointerDeviceKindSchema.schema,
    PopupMenuPositionSchema.id: PopupMenuPositionSchema.schema,
    PopupMenuThemeDataSchema.id: PopupMenuThemeDataSchema.schema,
    ProgressIndicatorThemeDataSchema.id:
        ProgressIndicatorThemeDataSchema.schema,
    RadioThemeDataSchema.id: RadioThemeDataSchema.schema,
    RadiusSchema.id: RadiusSchema.schema,
    RangeSliderThumbShapeSchema.id: RangeSliderThumbShapeSchema.schema,
    RangeSliderTickMarkShapeSchema.id: RangeSliderTickMarkShapeSchema.schema,
    RangeSliderTrackShapeSchema.id: RangeSliderTrackShapeSchema.schema,
    RangeSliderValueIndicatorShapeSchema.id:
        RangeSliderValueIndicatorShapeSchema.schema,
    RectSchema.id: RectSchema.schema,
    ScrollBehaviorSchema.id: ScrollBehaviorSchema.schema,
    ScrollPhysicsSchema.id: ScrollPhysicsSchema.schema,
    ScrollViewKeyboardDismissBehaviorSchema.id:
        ScrollViewKeyboardDismissBehaviorSchema.schema,
    ScrollbarOrientationSchema.id: ScrollbarOrientationSchema.schema,
    ScrollbarThemeDataSchema.id: ScrollbarThemeDataSchema.schema,
    SemanticsTagSchema.id: SemanticsTagSchema.schema,
    ShadowSchema.id: ShadowSchema.schema,
    ShapeBorderSchema.id: ShapeBorderSchema.schema,
    ShowValueIndicatorSchema.id: ShowValueIndicatorSchema.schema,
    SizeSchema.id: SizeSchema.schema,
    SliderComponentShapeSchema.id: SliderComponentShapeSchema.schema,
    SliderThemeDataSchema.id: SliderThemeDataSchema.schema,
    SliderTickMarkShapeSchema.id: SliderTickMarkShapeSchema.schema,
    SliderTrackShapeSchema.id: SliderTrackShapeSchema.schema,
    SmartDashesTypeSchema.id: SmartDashesTypeSchema.schema,
    SmartQuotesTypeSchema.id: SmartQuotesTypeSchema.schema,
    SnackBarBehaviorSchema.id: SnackBarBehaviorSchema.schema,
    SnackBarThemeDataSchema.id: SnackBarThemeDataSchema.schema,
    StackFitSchema.id: StackFitSchema.schema,
    StrutStyleSchema.id: StrutStyleSchema.schema,
    SwitchThemeDataSchema.id: SwitchThemeDataSchema.schema,
    SystemUiOverlayStyleSchema.id: SystemUiOverlayStyleSchema.schema,
    TabBarIndicatorSizeSchema.id: TabBarIndicatorSizeSchema.schema,
    TabBarThemeSchema.id: TabBarThemeSchema.schema,
    TableBorderSchema.id: TableBorderSchema.schema,
    TableColumnWidthSchema.id: TableColumnWidthSchema.schema,
    TargetPlatformSchema.id: TargetPlatformSchema.schema,
    TextAlignSchema.id: TextAlignSchema.schema,
    TextAlignVerticalSchema.id: TextAlignVerticalSchema.schema,
    TextBaselineSchema.id: TextBaselineSchema.schema,
    TextButtonThemeDataSchema.id: TextButtonThemeDataSchema.schema,
    TextCapitalizationSchema.id: TextCapitalizationSchema.schema,
    TextDecorationSchema.id: TextDecorationSchema.schema,
    TextDecorationStyleSchema.id: TextDecorationStyleSchema.schema,
    TextDirectionSchema.id: TextDirectionSchema.schema,
    TextHeightBehaviorSchema.id: TextHeightBehaviorSchema.schema,
    TextInputActionSchema.id: TextInputActionSchema.schema,
    TextInputTypeSchema.id: TextInputTypeSchema.schema,
    TextLeadingDistributionSchema.id: TextLeadingDistributionSchema.schema,
    TextOverflowSchema.id: TextOverflowSchema.schema,
    TextSelectionThemeDataSchema.id: TextSelectionThemeDataSchema.schema,
    TextSpanSchema.id: TextSpanSchema.schema,
    TextStyleSchema.id: TextStyleSchema.schema,
    TextThemeSchema.id: TextThemeSchema.schema,
    TextWidthBasisSchema.id: TextWidthBasisSchema.schema,
    ThemeDataSchema.id: ThemeDataSchema.schema,
    TileModeSchema.id: TileModeSchema.schema,
    TimePickerThemeDataSchema.id: TimePickerThemeDataSchema.schema,
    ToggleButtonsThemeDataSchema.id: ToggleButtonsThemeDataSchema.schema,
    TooltipThemeDataSchema.id: TooltipThemeDataSchema.schema,
    TooltipTriggerModeSchema.id: TooltipTriggerModeSchema.schema,
    TypographySchema.id: TypographySchema.schema,
    VerticalDirectionSchema.id: VerticalDirectionSchema.schema,
    VisualDensitySchema.id: VisualDensitySchema.schema,
    WrapAlignmentSchema.id: WrapAlignmentSchema.schema,
    WrapCrossAlignmentSchema.id: WrapCrossAlignmentSchema.schema,
  };
}
